==> jc-1.4.0.tar.gz: java/awt/Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler.h <==
// public class java.awt.Component$AccessibleAWTComponent$AccessibleAWTFocusHandler

// class file dependencies
// @dep_class da8b60e085fc3449 java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler_H_
#define _JC_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler_H_

// Forward structure declarations
struct _jc_java_awt_Component__24AccessibleAWTComponent$object;
struct _jc_java_awt_event_FocusEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$sub_refs	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$sub_refs;
typedef struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$sub_nonrefs	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$sub_nonrefs;
typedef struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$refs	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$refs;
typedef struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$nonrefs	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$nonrefs;
typedef struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$object	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$object;

typedef const struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vmethods	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vmethods;
typedef const struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vtable	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vtable;
typedef const struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vtype	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vtype;

// Constructors
extern void _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$method$_init$e04fee3361fa61e5(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$object *, struct _jc_java_awt_Component__24AccessibleAWTComponent$object *);

// Virtual methods
extern void _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$method$focusGained$2b0b3146a729e224(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *);
extern void _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$method$focusLost$b4af7a719a65818b(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$method_info$focusGained$2b0b3146a729e224;
extern _jc_method _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$method_info$focusLost$b4af7a719a65818b;

// Virtual methods structure
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vmethods {
	void	(*focusGained$2b0b3146a729e224)(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *);
	void	(*focusLost$b4af7a719a65818b)(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *);
};

// Vtable
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vmethods	java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler;
};

// Vtype
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vtype {
	_jc_type			type;
	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$sub_refs {
	struct _jc_java_awt_Component__24AccessibleAWTComponent$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$refs {
    _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$sub_refs	java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler;
};

// Object instance structure
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$object {
	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vtype	*vtype;
	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vtype _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$class_object;

#endif	/* _JC_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler_H_ */

==> jc-1.4.5.tar.gz: java/awt/Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler.h <==
// public class java.awt.Component$AccessibleAWTComponent$AccessibleAWTFocusHandler

// class file dependencies
// @dep_class a9774ba60533db52 java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler_H_
#define _JC_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler_H_

// Forward structure declarations
struct _jc_java_awt_Component__24AccessibleAWTComponent$object;
struct _jc_java_awt_event_FocusEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$sub_refs	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$sub_refs;
typedef struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$sub_nonrefs	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$sub_nonrefs;
typedef struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$refs	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$refs;
typedef struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$nonrefs	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$nonrefs;
typedef struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$object	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$object;

typedef const struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vmethods	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vmethods;
typedef const struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vtable	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vtable;
typedef const struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vtype	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vtype;

// Constructors
extern void _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$method$_init$e04fee3361fa61e5(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$object *, struct _jc_java_awt_Component__24AccessibleAWTComponent$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$method$focusGained$2b0b3146a729e224(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$method$focusLost$b4af7a719a65818b(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$method_info$focusGained$2b0b3146a729e224;
extern _jc_method _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$method_info$focusLost$b4af7a719a65818b;

// Virtual methods structure
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vmethods {
	void	(*focusGained$2b0b3146a729e224)(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;
	void	(*focusLost$b4af7a719a65818b)(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$object *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vmethods	java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler;
};

// Vtype
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vtype {
	_jc_type			type;
	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$sub_refs {
	struct _jc_java_awt_Component__24AccessibleAWTComponent$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$refs {
    _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$sub_refs	java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler;
};

// Object instance structure
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$object {
	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vtype	*vtype;
	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$vtype _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler$class_object;

#endif	/* _JC_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTFocusHandler_H_ */
